==> deepin-home_1.5.5.tar.xz: BUILD/translations/deepin-home/fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>View details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 views</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Arrivant</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Communication</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discuter et partager ici</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Rapport d&apos;erreur</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Rapporter des erreurs que vous avez trouvées</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggestions</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Soumettre vos suggestions</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ressources</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Questionnaire</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Joindre US</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Tests internes</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Nouveauté pour la communauté</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Questionnaires</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Lancer au démarrage système</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sortir</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Accueil Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Vous n&apos;avez pas encore de message.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 messages</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Tout marquer comme lu</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Voire plus</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Accueil Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Il n&apos;y a pas encore de questionnaire.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Expiré le : %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Remplir</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Resolved</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Evaluating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Info：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Information</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-home_1.5.10.tar.xz: BUILD/translations/deepin-home/fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>API</name>
    <message>
        <source>Please log in with your Deepin ID.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to log in to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>APIProxy</name>
    <message>
        <source>You have been making too many requests, Please try again later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You need to login to proceed with the subsequent operations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error, please try later.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountButton</name>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unlogged</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sign in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card</name>
    <message>
        <source>%1 views</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel the urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Card1</name>
    <message>
        <source>Coming</source>
        <translation>Arrivant</translation>
    </message>
</context>
<context>
    <name>Detail</name>
    <message>
        <source>Official response</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Filter</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Newest</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Urge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sort:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <source>Communication</source>
        <translation>Communication</translation>
    </message>
    <message>
        <source>Discuss and share here</source>
        <translation>Discuter et partager ici</translation>
    </message>
    <message>
        <source>Bug Report</source>
        <translation>Rapport d&apos;erreur</translation>
    </message>
    <message>
        <source>Report issues you found</source>
        <translation>Rapporter des erreurs que vous avez trouvées</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Suggestions</translation>
    </message>
    <message>
        <source>Submit your suggestions</source>
        <translation>Soumettre vos suggestions</translation>
    </message>
    <message>
        <source>Resources</source>
        <translation>Ressources</translation>
    </message>
    <message>
        <source>Questionaire</source>
        <translation>Questionnaire</translation>
    </message>
    <message>
        <source>Join US</source>
        <translation>Joindre US</translation>
    </message>
    <message>
        <source>Internal Testing</source>
        <translation>Tests internes</translation>
    </message>
    <message>
        <source>Community News</source>
        <translation>Nouveauté pour la communauté</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <source>Messages</source>
        <translation>Messages</translation>
    </message>
    <message>
        <source>Questionaires</source>
        <translation>Questionnaires</translation>
    </message>
    <message>
        <source>No more items</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <source>Launch at system startup</source>
        <translation>Lancer au démarrage système</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Sortir</translation>
    </message>
    <message>
        <source>Deepin Home</source>
        <translation>Accueil Deepin</translation>
    </message>
    <message>
        <source>Quick login to forums, submit suggestions, and report bugs.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>No messages yet.</source>
        <translation>Vous n&apos;avez pas encore de message.</translation>
    </message>
    <message>
        <source>%1 messages</source>
        <translation>%1 messages</translation>
    </message>
    <message>
        <source>Mark all as read</source>
        <translation>Tout marquer comme lu</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <source>View more</source>
        <translation>Voire plus</translation>
    </message>
</context>
<context>
    <name>Offline</name>
    <message>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <source>Deepin Home</source>
        <translation>Accueil Deepin</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <source>No questionaires yet.</source>
        <translation>Il n&apos;y a pas encore de questionnaire.</translation>
    </message>
    <message>
        <source>Expired on: %1</source>
        <translation>Expiré le : %1</translation>
    </message>
    <message>
        <source>Fill In</source>
        <translation>Remplir</translation>
    </message>
</context>
<context>
    <name>Status</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replied</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Resolved</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Evaluating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Accepted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Completed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reproducing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has not been processed and will not be displayed in the public listing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Currently unable to identify the cause; continuous monitoring and investigation are required.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been reproduced and the root cause has been identified.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue is not a bug or of a different nature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been resolved and awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement has not been processed and will not be displayed in the public listing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The issue has been acknowledged and is being internally assessed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Included in the plans for a future release</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The requirement is either not accepted or unable to be addressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development work is finished, awaiting formal release</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Submit</name>
    <message>
        <source>Unable to add a screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file size should be less than 1MB.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The image file format is not supported for uploading.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Current Status of the Product]: 
[Desired Product]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[Preconditions]: 
[Reproducibility Steps]: 
[Expected Results]: 
[Actual Results]: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Type：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bug Report</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Title：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide a brief description of your issue</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Content：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple requirements in one feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Email：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Info：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload &lt;a href=&apos;home://sysinfo&apos;&gt;device information&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshots：</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Drag and drop files or click buttons to add pictures, up to three</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to exit the feedback submission?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The feedback content will not be saved.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to submit feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title and content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the title of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please provide the content of your feedback.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect email address entered.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device Information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter your email</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not fill in multiple issues in one feedback</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabButton</name>
    <message>
        <source>Feedback Hub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Feedbacks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Urged</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
